@@ -55,16 +55,16 @@ check_servers (DryadApp *app)
 static void
 load_file (DryadApp *app, gchar *filename)
 {
-    gboolean success;
+    GdfDebuggerClientResult res;
 
     if (!dryad_load_debugger (app))
         return;
     
-    success = gdf_debugger_client_load_binary (app->dbg, filename);
-    if (success) {
+    res = gdf_debugger_client_load_binary (app->dbg, filename);
+    if (res == GDF_DEBUGGER_CLIENT_OK) {
         gdf_debugger_client_set_breakpoint_function (app->dbg, 
                                                      NULL, "main",
-                                                     NULL);
+                                                     NULL, NULL);
         app->binary_name = g_strdup (filename);
     } else {
         GtkWidget *app_widget;
@@ -88,7 +88,7 @@ init_app (gchar *filename)
     if (filename)
         load_file (app, filename);
 
-    gtk_timeout_add (SERVER_CHECK_TIMEOUT, check_servers, app);
+    gtk_timeout_add (SERVER_CHECK_TIMEOUT, (GtkFunction)check_servers, app);
 
 	return FALSE;
 }
@@ -108,7 +108,6 @@ int
 main (int argc, char *argv[])
 {
 	CORBA_Environment ev;
-	CORBA_ORB orb;
 
     gchar *filename = NULL;
 
