@@ -82,6 +82,8 @@ static void widget_destruction_func (DryadApp *app, GtkWidget *w, void *data);
 static void load_cb (GtkWidget *widget, DryadApp *app);
 static void unload_cb (GtkWidget *widget, DryadApp *app);
 static void run_cb (GtkWidget *widget, DryadApp *app);
+static void attach_cb (GtkWidget *widget, DryadApp *app);
+static void detach_cb (GtkWidget *widget, DryadApp *app);
 static void stop_cb (GtkWidget *widget, DryadApp *app);
 static void step_into_cb (GtkWidget *widget, DryadApp *app);
 static void step_over_cb (GtkWidget *widget, DryadApp *app);
@@ -262,6 +264,12 @@ init_main_frame (DryadApp *app)
 	widget = glade_xml_get_widget (app->ui, "run_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (run_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "attach_btn");
+	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
+						GTK_SIGNAL_FUNC (attach_cb), (gpointer) app);
+	widget = glade_xml_get_widget (app->ui, "detach_btn");
+	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
+						GTK_SIGNAL_FUNC (detach_cb), (gpointer) app);
 	widget = glade_xml_get_widget (app->ui, "stop_btn");
 	gtk_signal_connect (GTK_OBJECT (widget), "clicked", 
 						GTK_SIGNAL_FUNC (stop_cb), (gpointer) app);
@@ -483,27 +491,38 @@ unload_cb (GtkWidget *widget, DryadApp *app)
     dryad_unload_debugger (app);
 }
 
-void
+void 
 run_cb (GtkWidget *widget, DryadApp *app)
 {
-	GDF_Debugger_State state;
+	GDF_Debugger_StateFlag state;
 	/* FIXME: Get arguments from the user */
 	gchar *argv[1];
 	
 	g_assert (app->binary_name != NULL);
 	
 	state = gdf_debugger_client_get_state (app->dbg);
-	
-	GDF_TRACE_EXTRA ("%d", state);
+
 	argv[0] = app->binary_name;
 	
-	if (state == GDF_Debugger_NONE) {
+	if ((state & GDF_Debugger_TARGET_EXISTS) != GDF_Debugger_TARGET_EXISTS) {
 		gdf_debugger_client_execute (app->dbg, 1, argv);
 	} else {
 		gdf_debugger_client_cont (app->dbg);
 	}
 }
 
+void
+attach_cb (GtkWidget *widget, DryadApp *app)
+{
+    gdf_attach_dialog (app->dbg);
+}
+
+void 
+detach_cb (GtkWidget *widget, DryadApp *app)
+{
+    gdf_debugger_client_detach (app->dbg);
+}
+
 void
 stop_cb (GtkWidget *widget, DryadApp *app)
 {
@@ -555,7 +574,7 @@ typedef struct
 static gint
 load_file (FileSelectedIdleData *data)
 {
-    gboolean success;
+    GdfDebuggerClientResult res;
 
     if (data->app->binary_name != NULL) {
         gdf_debugger_client_unload_binary (data->app->dbg);
@@ -571,12 +590,12 @@ load_file (FileSelectedIdleData *data)
         return FALSE;
     }   
     
-    success = gdf_debugger_client_load_binary (data->app->dbg, 
-                                                data->filename);
-    if (success) {
+    res = gdf_debugger_client_load_binary (data->app->dbg, 
+                                           data->filename);
+    if (res == GDF_DEBUGGER_CLIENT_OK) {
         gdf_debugger_client_set_breakpoint_function (data->app->dbg, 
-                                                      NULL, "main",
-                                                      NULL);
+                                                     NULL, "main",
+                                                     NULL, NULL);
         data->app->binary_name = g_strdup (data->filename);
     } else {
         GtkWidget *app_widget;
